@@ -1,6 +1,6 @@
 package Pcore::Selenium::Firefox::Profile;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 1;
 __END__
